==> jc-1.4.0.tar.gz: soot/dava/internal/SET/SETDagNode.h <==
// public abstract class soot.dava.internal.SET.SETDagNode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5fe8043c911a8f07 soot_dava_internal_SET_SETControlFlowNode
// @dep_class 1df4134650bc1e83 soot_dava_internal_SET_SETDagNode
// @dep_class 4d3d060182af30b5 soot_dava_internal_SET_SETNode

// header file dependencies
// @dep_header soot_dava_internal_SET_SETControlFlowNode

#include "soot/dava/internal/SET/SETControlFlowNode.h"

#ifndef _JC_soot_dava_internal_SET_SETDagNode_H_
#define _JC_soot_dava_internal_SET_SETDagNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_dava_internal_asg_AugmentedStmt$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_internal_SET_SETDagNode$sub_refs	_jc_soot_dava_internal_SET_SETDagNode$sub_refs;
typedef struct _jc_soot_dava_internal_SET_SETDagNode$sub_nonrefs	_jc_soot_dava_internal_SET_SETDagNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETDagNode$refs	_jc_soot_dava_internal_SET_SETDagNode$refs;
typedef struct _jc_soot_dava_internal_SET_SETDagNode$nonrefs	_jc_soot_dava_internal_SET_SETDagNode$nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETDagNode$object	_jc_soot_dava_internal_SET_SETDagNode$object;

typedef const struct _jc_soot_dava_internal_SET_SETDagNode$vmethods	_jc_soot_dava_internal_SET_SETDagNode$vmethods;
typedef const struct _jc_soot_dava_internal_SET_SETDagNode$vtable	_jc_soot_dava_internal_SET_SETDagNode$vtable;
typedef const struct _jc_soot_dava_internal_SET_SETDagNode$vtype	_jc_soot_dava_internal_SET_SETDagNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_SET_SETDagNode$method$_init$88b2f90f98cac172(_jc_env *, struct _jc_soot_dava_internal_SET_SETDagNode$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *, struct _jc_soot_util_IterableSet$object *);

// Virtual methods
extern struct _jc_soot_dava_internal_asg_AugmentedStmt$object *_jc_soot_dava_internal_SET_SETDagNode$method$get__5fEntryStmt$d3b7a698292e24c9(_jc_env *, struct _jc_soot_dava_internal_SET_SETDagNode$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_SET_SETDagNode$method_info$get__5fEntryStmt$d3b7a698292e24c9;

// Virtual methods structure
struct _jc_soot_dava_internal_SET_SETDagNode$vmethods {
	struct _jc_soot_dava_internal_asg_AugmentedStmt$object	*(*get__5fEntryStmt$d3b7a698292e24c9)(_jc_env *, struct _jc_soot_dava_internal_SET_SETDagNode$object *);
};

// Vtable
struct _jc_soot_dava_internal_SET_SETDagNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_internal_SET_SETNode$vmethods	soot_dava_internal_SET_SETNode;
	_jc_soot_dava_internal_SET_SETControlFlowNode$vmethods	soot_dava_internal_SET_SETControlFlowNode;
	_jc_soot_dava_internal_SET_SETDagNode$vmethods	soot_dava_internal_SET_SETDagNode;
};

// Vtype
struct _jc_soot_dava_internal_SET_SETDagNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_SET_SETDagNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETDagNode$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETDagNode$refs {
    _jc_soot_dava_internal_SET_SETDagNode$sub_refs	soot_dava_internal_SET_SETDagNode;
    _jc_soot_dava_internal_SET_SETControlFlowNode$sub_refs	soot_dava_internal_SET_SETControlFlowNode;
    _jc_soot_dava_internal_SET_SETNode$sub_refs	soot_dava_internal_SET_SETNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETDagNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETDagNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_internal_SET_SETNode$sub_nonrefs	soot_dava_internal_SET_SETNode;
    _jc_soot_dava_internal_SET_SETControlFlowNode$sub_nonrefs	soot_dava_internal_SET_SETControlFlowNode;
    _jc_soot_dava_internal_SET_SETDagNode$sub_nonrefs	soot_dava_internal_SET_SETDagNode;
};

// Object instance structure
struct _jc_soot_dava_internal_SET_SETDagNode$object {
	_jc_soot_dava_internal_SET_SETDagNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_SET_SETDagNode$vtype	*vtype;
	_jc_soot_dava_internal_SET_SETDagNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_SET_SETDagNode$vtype _jc_soot_dava_internal_SET_SETDagNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_SET_SETDagNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_SET_SETDagNode$class_object;

#endif	/* _JC_soot_dava_internal_SET_SETDagNode_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/SET/SETDagNode.h <==
// public abstract class soot.dava.internal.SET.SETDagNode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5fe8043c911a8f07 soot_dava_internal_SET_SETControlFlowNode
// @dep_class 1df4134650bc1e83 soot_dava_internal_SET_SETDagNode
// @dep_class 4d3d060182af30b5 soot_dava_internal_SET_SETNode

// header file dependencies
// @dep_header soot_dava_internal_SET_SETControlFlowNode

#include "soot/dava/internal/SET/SETControlFlowNode.h"

#ifndef _JC_soot_dava_internal_SET_SETDagNode_H_
#define _JC_soot_dava_internal_SET_SETDagNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_dava_internal_asg_AugmentedStmt$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_internal_SET_SETDagNode$sub_refs	_jc_soot_dava_internal_SET_SETDagNode$sub_refs;
typedef struct _jc_soot_dava_internal_SET_SETDagNode$sub_nonrefs	_jc_soot_dava_internal_SET_SETDagNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETDagNode$refs	_jc_soot_dava_internal_SET_SETDagNode$refs;
typedef struct _jc_soot_dava_internal_SET_SETDagNode$nonrefs	_jc_soot_dava_internal_SET_SETDagNode$nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETDagNode$object	_jc_soot_dava_internal_SET_SETDagNode$object;

typedef const struct _jc_soot_dava_internal_SET_SETDagNode$vmethods	_jc_soot_dava_internal_SET_SETDagNode$vmethods;
typedef const struct _jc_soot_dava_internal_SET_SETDagNode$vtable	_jc_soot_dava_internal_SET_SETDagNode$vtable;
typedef const struct _jc_soot_dava_internal_SET_SETDagNode$vtype	_jc_soot_dava_internal_SET_SETDagNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_SET_SETDagNode$method$_init$88b2f90f98cac172(_jc_env *, struct _jc_soot_dava_internal_SET_SETDagNode$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *, struct _jc_soot_util_IterableSet$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_dava_internal_asg_AugmentedStmt$object *_jc_soot_dava_internal_SET_SETDagNode$method$get__5fEntryStmt$d3b7a698292e24c9(_jc_env *, struct _jc_soot_dava_internal_SET_SETDagNode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_SET_SETDagNode$method_info$get__5fEntryStmt$d3b7a698292e24c9;

// Virtual methods structure
struct _jc_soot_dava_internal_SET_SETDagNode$vmethods {
	struct _jc_soot_dava_internal_asg_AugmentedStmt$object	*(*get__5fEntryStmt$d3b7a698292e24c9)(_jc_env *, struct _jc_soot_dava_internal_SET_SETDagNode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_SET_SETDagNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_internal_SET_SETNode$vmethods	soot_dava_internal_SET_SETNode;
	_jc_soot_dava_internal_SET_SETControlFlowNode$vmethods	soot_dava_internal_SET_SETControlFlowNode;
	_jc_soot_dava_internal_SET_SETDagNode$vmethods	soot_dava_internal_SET_SETDagNode;
};

// Vtype
struct _jc_soot_dava_internal_SET_SETDagNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_SET_SETDagNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETDagNode$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETDagNode$refs {
    _jc_soot_dava_internal_SET_SETDagNode$sub_refs	soot_dava_internal_SET_SETDagNode;
    _jc_soot_dava_internal_SET_SETControlFlowNode$sub_refs	soot_dava_internal_SET_SETControlFlowNode;
    _jc_soot_dava_internal_SET_SETNode$sub_refs	soot_dava_internal_SET_SETNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETDagNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETDagNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_internal_SET_SETNode$sub_nonrefs	soot_dava_internal_SET_SETNode;
    _jc_soot_dava_internal_SET_SETControlFlowNode$sub_nonrefs	soot_dava_internal_SET_SETControlFlowNode;
    _jc_soot_dava_internal_SET_SETDagNode$sub_nonrefs	soot_dava_internal_SET_SETDagNode;
};

// Object instance structure
struct _jc_soot_dava_internal_SET_SETDagNode$object {
	_jc_soot_dava_internal_SET_SETDagNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_SET_SETDagNode$vtype	*vtype;
	_jc_soot_dava_internal_SET_SETDagNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_SET_SETDagNode$vtype _jc_soot_dava_internal_SET_SETDagNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_SET_SETDagNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_SET_SETDagNode$class_object;

#endif	/* _JC_soot_dava_internal_SET_SETDagNode_H_ */
